@@ -27,7 +27,7 @@ from rez.suite import Suite
 from rez.wrapper import Wrapper
 from rez.utils.colorize import warning, critical, Printer
 from rez.utils.formatting import print_colored_columns, PackageRequest
-from rez.backport.shutilwhich import which
+from rez.utils.which import which
 
 
 class Status(object):
